@@ -2,7 +2,7 @@
                           rkvariable  -  description
                              -------------------
     begin                : Thu Aug 12 2004
-    copyright            : (C) 2004, 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2007, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -17,7 +17,7 @@
 #ifndef RKVARIABLE_H
 #define RKVARIABLE_H
 
-#include <qstring.h>
+#include <QStringList>
 #include <QHash>
 
 #include "robject.h"
@@ -54,7 +54,7 @@ is set to Unused, if _no_ cell in the row is used, Valid if _all_ cells in the r
 	enum Status { ValueUnused=0, ValueValid=1, ValueInvalid=2, ValueUnknown=4 };
 
 /** sets whether changed data should be synced immediately or not. Set this to off for large paste operations. Rember to call setSyncing (true) and syncDataToR () after the paste is complete */
-	void setSyncing (bool immediate);
+	void lockSyncing (bool lock);
 /** syncs pending data changes to the backend */
 	void syncDataToR ();
 /** reimplemented from RObject */
@@ -66,32 +66,18 @@ is set to Unused, if _no_ cell in the row is used, Valid if _all_ cells in the r
 /** get the value at the given row in text-form suitable for submission to R. I.e. strings are quoted, numbers are not, empty values are returned as NA */
 	QString getRText (int row) const;
 /** set the value at the given row in text-form. Will try to convert the given string to the internal storage format if possible. */
-	void setText (int row, const QString &text);
+	virtual void setText (int row, const QString &text);
 
-/** get a copy of the numeric values of rows starting from from_index, going to to_index. Do not use this before making sure that the rStorage () is really
-numeric!  TODO: unused  */
-	double *getNumeric (int from_row, int to_row) const;
-/** set numeric values in the given range. Assumes you provide enough values for the range. If internalStorage is String, all values will be converted to strings, so you should use this function only, if you know you are dealing with a numeric object */
-	void setNumeric (int from_row, int to_row, double *data);
-/** like getNumeric, but returns values as an array of QStrings. TODO: unused */
+/** get a copy of the text values of rows from from_index to to_index. TODO: This could be made, but currently is not, more efficient than calling getText in a loop. */
 	QString *getCharacter (int from_row, int to_row) const;
-/** like setNumeric, but sets chars. If internalStorage () is numeric, attempts to convert the given strings to numbers. I.e. the function behaves essentially like setText (), but operates on a range of cells. */
-	void setCharacter (int from_row, int to_row, QString *data);
 	
 /** returns the current status of the given cell */
 	Status cellStatus (int row) const;
 
-/** sets the status of the given range of cells to Unknown (the entire row if from_row and to_row are -1). Usually you call this, when you are about to update the given data-range, but haven't fetched the data for that, yet. The unknown-flag is cleared for the cells, as soon as data is written to those cells. The effect is that the cells will not be editable until the data was updated. */
-	void setUnknown (int from_row=-1, int to_row=-1);
-
-/** entirely remove the given row (i.e. the cell). Will also take care of updating the state (are there any invalid cells left?). Does not sync with the backend for technical reasons! You have to remove the row in the backend explicitly. */
-	void removeRow (int row);
-/** see removeRow (), but removes a range of rows (i.e. cells). Since data only needs to be copied once, this is more efficient than several single calls to removeRow (). Does not sync with the backend for technical reasons! You have to remove the row in the backend explicitly. */
-	void removeRows (int from_row, int to_row);
-/** inserts a row/cell (with empty value) just above the given index. Does not sync with the backend for technical reasons! You have to insert the row in the backend explicitly. */
-	void insertRow (int row);
-/** like insertRow (), but inserts count rows. Does not sync with the backend for technical reasons! You have to insert the row in the backend explicitly. */
-	void insertRows (int row, int count);
+/** entirely remove the given rows (i.e. the cells). Will also take care of updating the state (are there any invalid cells left?). Does not sync with the backend for technical reasons! You have to remove the row in the backend explicitly. */
+	virtual void removeRows (int from_row, int to_row);
+/** inserts count rows (with empty values) just above the given index. Does not sync with the backend for technical reasons! You have to insert the row in the backend explicitly. */
+	virtual void insertRows (int row, int count);
 /** Tells the object it has (data) length len. Usually this will only be called directly after creating a new object */
 	void setLength (int len);
 
@@ -141,12 +127,18 @@ numeric!  TODO: unused  */
 /** inverse of parseFormattingOptionsString () */
 	static QString formattingOptionsToString (const FormattingOptions& options);
 protected:
+/** Discards pending unsynced changes. */
+	void discardUnsyncedChanges ();
+/** like setNumeric, but sets chars. If internalStorage () is numeric, attempts to convert the given strings to numbers. I.e. the function behaves essentially like setText (), but operates on a range of cells. Code may assume that all data comes directly from R, is entirely valid in R. */
+	virtual void setCharacterFromR (int from_row, int to_row, QString *data);
+/** set numeric values in the given range. Assumes you provide enough values for the range. If internalStorage is String, all values will be converted to strings, so you should use this function only, if you know you are dealing with a numeric object. Code may assume that all data comes directly from R, is entirely valid in R. */
+	void setNumericFromR (int from_row, int to_row, double *data);
 /** reimplemented from RObject to change the internal data storage mode, if the var is being edited */
 	bool updateType (RData *new_data);
 /** Extended from RObject::EditData to actually contain data. */
 	struct RKVarEditData {
-		QString *cell_strings;
-		double *cell_doubles;
+		QStringList cell_strings;
+		QList<double> cell_doubles;
 		enum CellState {
 			Unknown=0,
 			Invalid=1,
@@ -154,14 +146,12 @@ protected:
 			Valid=4,
 			UnsyncedInvalidState=8
 		};
-		int *cell_states;
+		QList<int> cell_states;
 
-/// the currently allocated length of cell_data and cell_states. Used to determine, when a re-allocation is required
-		int allocated_length;
 /// see setSyncing
-		bool immediate_sync;
+		int sync_locks;
 /// stores changes if syncing is not immediate
-		ChangeSet *changes;
+		ChangeSet changes;
 /// stores whether there were preivously invalid cells. If so, and there are no longer, now, we may change the mode in the backend.
 		bool previously_valid;
 /** the value-labels or factor levels assigned to this variable. 0 if no values/levels given. TODO: Should this be made a regular (non-pointer) member, or is the saved mem really worth the trouble? */
@@ -179,17 +169,15 @@ protected:
 	void beginEdit ();
 /** reimplemented from RObject */
 	void endEdit ();
-private:
+
 /** changes the allocated storage to contain a least length elements. More data may be allocated than acutally needed. This function only ever does upsizing. */
 	void extendToLength (int length);
 /** changes the allocated storage to contain a least getLength elements. More data may be allocated than acutally needed. This function only ever does downsizing. */
 	void downSize ();
-/** takes care of syncing the given cell */
-	void cellChanged (int row);
 /** takes care of syncing the given range of cells */
 	void cellsChanged (int from_row, int to_row);
 /** writes the given range of cells to the backend (regardless of whether syncing should be immediate) */
-	void writeData (int from_row, int to_row, RCommandChain *chain=0);
+	virtual void writeData (int from_row, int to_row, RCommandChain *chain=0);
 	void writeInvalidField (int row, RCommandChain *chain=0);
 /** writes the values labels to the backend */
 	void writeValueLabels (RCommandChain *chain) const;
@@ -200,22 +188,7 @@ private:
 	void allocateEditData ();
 /** discard edit data */
 	void discardEditData ();
-
-/** TODO: QStrings can't be memmoved. We should use QVector/QList instead. */
-	void memMoveQStrings (QString *dst, QString *src, int count) {
-		if (dst > src) {
-			for (int i = count - 1; i >= 0; --i) {
-				dst[i] = src[i];
-			}
-		} else {
-			for (int i = 0; i < count; ++i) {
-				dst[i] = src[i];
-			}
-		}
-	};
 /////////////////// END: data-handling //////////////////////
 };
 
-typedef RKVariable* RKVarPtr;
-
 #endif
