@@ -2,7 +2,7 @@
                           robject  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -29,6 +29,7 @@
 #include "renvironmentobject.h"
 #include "rfunctionobject.h"
 #include "rkmodificationtracker.h"
+#include "rkrownames.h"
 
 #include "../debug.h"
 
@@ -51,6 +52,7 @@ RObject::~RObject () {
 
 	delete [] dimensions;
 	delete [] classnames;
+	cancelOutstandingCommands ();
 }
 
 bool RObject::irregularShortName (const QString &name) {
@@ -314,16 +316,17 @@ void RObject::updateDataFromR (RCommandChain *) {
 	type -= (type & NeedDataUpdate);
 }
 
-#warning probably we do not really need this. Rather we should always call updateDataFromR recursively, and that will take care of things. (make sure not to overwrite pending changes, though)
 void RObject::markDataDirty () {
 	RK_TRACE (OBJECTS);
 
 	type |= NeedDataUpdate;
 	if (isContainer ()) {
-		RObjectMap children = static_cast<RContainerObject*> (this)->childmap;
+	    RContainerObject* this_container = static_cast<RContainerObject*> (this);
+		RObjectMap children = this_container->childmap;
 		for (int i = children.size () - 1; i >= 0; --i) {
 			children[i]->markDataDirty ();
 		}
+		if (this_container->rownames_object) this_container->rownames_object->markDataDirty ();
 	}
 }
 
