@@ -2,7 +2,7 @@
                           rkvareditmodel  -  description
                              -------------------
     begin                : Mon Nov 05 2007
-    copyright            : (C) 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2007, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -19,8 +19,12 @@
 
 #include <klocale.h>
 
+#include <QColor>
+#include <QTimer>
+
 #include "../core/rcontainerobject.h"
 #include "../core/rkmodificationtracker.h"
+#include "../core/rkrownames.h"
 #include "../rbackend/rinterface.h"
 #include "../rkglobals.h"
 
@@ -31,7 +35,11 @@ RKVarEditModel::RKVarEditModel (QObject *parent) : RKVarEditModelBase (parent),
 
 	meta_model = 0;
 	trailing_rows = trailing_cols = 0;
+	var_col_offset = 0;
 	edit_blocks = 0;
+	rownames = 0;
+	header_locked = false;
+	duplicate_check_triggered = false;
 
 	addNotificationType (RObjectListener::ObjectRemoved);
 	addNotificationType (RObjectListener::MetaChanged);
@@ -67,13 +75,19 @@ void RKVarEditModel::addObject (int index, RKVariable* object) {
 	objects.insert (index, object);
 	if (meta_model) meta_model->endAddDataObject ();
 	endInsertColumns ();
+
+	checkDuplicates ();
 }
 
 void RKVarEditModel::objectRemoved (RObject* object) {
 	RK_TRACE (EDITOR);
 
 	int index = objects.indexOf (static_cast<RKVariable*> (object));	// no check for isVariable needed. we only need to look up, if we have this object, and where.
-	if (index < 0) return;	// none of our buisiness
+	if (index < var_col_offset) {
+		if (index < 0) return;	// e.g. the data.frame object
+		// the rownames object should only be deleted, when the whole data.frame is gone)
+		RK_ASSERT (objects.size () <= var_col_offset);
+	}
 
 	beginRemoveColumns (QModelIndex (), index, index);
 	if (meta_model) meta_model->beginRemoveDataObject (index);
@@ -81,7 +95,36 @@ void RKVarEditModel::objectRemoved (RObject* object) {
 	if (meta_model) meta_model->endRemoveDataObject ();
 	endRemoveColumns ();
 
-	if (objects.isEmpty ()) emit (modelDepleted ());	// editor may or may want to auto-destruct
+	if (objects.size () <= var_col_offset) emit (modelDepleted ());	// editor may or may want to auto-destruct
+}
+
+void RKVarEditModel::checkDuplicates () {
+	RK_TRACE (EDITOR);
+
+	if (duplicate_check_triggered) return;
+	duplicate_check_triggered = true;
+	QTimer::singleShot (0, this, SLOT (checkDuplicatesNow()));
+}
+
+void RKVarEditModel::checkDuplicatesNow () {
+	RK_TRACE (EDITOR);
+
+	duplicate_check_triggered = false;
+
+	QStringList dupes;
+	for (int i = var_col_offset; i < objects.size (); ++i) {
+		QString name = objects[i]->getShortName ();
+		for (int j = i+1; j < objects.size (); ++j) {
+			if (objects[j]->getShortName () == name) {
+				if (objects[i]->getFullName () == objects[j]->getFullName ()) {
+					dupes.append (objects[i]->getFullName ());
+					j = objects.size ();		// break
+				}
+			}
+		}
+	}
+
+	if (!dupes.isEmpty ()) emit (hasDuplicates (dupes));
 }
 
 void RKVarEditModel::objectMetaChanged (RObject* changed) {
@@ -131,11 +174,12 @@ bool RKVarEditModel::insertRows (int row, int count, const QModelIndex& parent)
 	RK_ASSERT (lastrow >= row);
 
 	beginInsertRows (QModelIndex (), row, row+count-1);
+	doInsertRowsInBackend (row, count);
 	for (int i=0; i < objects.size (); ++i) {
 // TODO: this does not emit any data change notifications to other editors
 		objects[i]->insertRows (row, count);
 	}
-	doInsertRowsInBackend (row, count);
+#warning TODO: adjust dimensions of the data.frame!
 	endInsertRows ();
 
 	return true;
@@ -154,11 +198,11 @@ bool RKVarEditModel::removeRows (int row, int count, const QModelIndex& parent)
 	RK_ASSERT (lastrow >= row);
 
 	beginRemoveRows (QModelIndex (), row, lastrow);
+	doRemoveRowsInBackend (row, lastrow - row + 1);
 	for (int i=0; i < objects.size (); ++i) {
 // TODO: this does not emit any data change notifications to other editors
 		objects[i]->removeRows (row, lastrow);
 	}
-	doRemoveRowsInBackend (row, lastrow - row + 1);
 	endRemoveRows ();
 
 	return true;
@@ -207,6 +251,11 @@ QVariant RKVarEditModel::data (const QModelIndex& index, int role) const {
 		return QVariant ();
 	}
 
+	if (col < var_col_offset) {
+		// TODO: make this look more like a normal header
+		if (role == Qt::ForegroundRole) return (Qt::blue);
+	}
+
 	// on a trailing row / col
 	if ((col >= objects.size ()) || (row >= objects[0]->getLength ())) {
 		if (role == Qt::BackgroundRole) return (Qt::gray);
@@ -225,7 +274,9 @@ QVariant RKVarEditModel::data (const QModelIndex& index, int role) const {
 	if (role == Qt::EditRole) return var->getText (row, false);
 
 	RKVariable::Status status = var->cellStatus (row);
-	if ((role == Qt::BackgroundRole) && (status == RKVariable::ValueInvalid)) return (Qt::red);
+	if ((role == Qt::BackgroundRole)) {
+		if (status == RKVariable::ValueInvalid) return (Qt::red);
+	}
 	if ((role == Qt::ForegroundRole) && (status == RKVariable::ValueUnknown)) return (Qt::lightGray);
 	if (role == Qt::TextAlignmentRole) {
 		if (var->getAlignment () == RKVariable::AlignCellLeft) return ((int) Qt::AlignLeft | Qt::AlignVCenter);
@@ -248,6 +299,8 @@ Qt::ItemFlags RKVarEditModel::flags (const QModelIndex& index) const {
 		return flags;
 	}
 
+	if ((col < var_col_offset) && header_locked) return flags;
+
 	if (!edit_blocks) flags |= Qt::ItemIsEditable | Qt::ItemIsEnabled;
 	if ((col < objects.size ()) && (row < objects[0]->getLength ())) flags |= Qt::ItemIsSelectable;
 
@@ -295,7 +348,11 @@ QVariant RKVarEditModel::headerData (int section, Qt::Orientation orientation, i
 		return objects[section]->getShortName ();
 	}
 
-	return QString::number (section + 1);
+	if (section < rownames->getLength ()) {
+		return rownames->getText (section);
+	}
+
+	return QVariant ();
 }
 
 RKTextMatrix RKVarEditModel::getTextMatrix (const QItemSelectionRange& range) const {
@@ -369,10 +426,11 @@ void RKVarEditModel::setTextMatrix (const QModelIndex& offset, const RKTextMatri
 	int tcol = 0;
 	for (int col = left; col <= right; ++col) {
 		RKVariable* var = objects[col];
-		QString* data = text.getColumn (tcol);
-		RK_ASSERT (data);
-		var->setCharacter (top, bottom, data);
-		delete [] data;		// hm, why doesn't RKVariable take ownership?
+		int trow = 0;
+		for (int row = top; row <= bottom; ++row) {
+			var->setText (row, text.getText (trow, tcol));
+			++trow;
+		}
 		++tcol;
 	}
 }
@@ -451,6 +509,11 @@ QVariant RKVarEditMetaModel::data (const QModelIndex& index, int role) const {
 		return QVariant ();
 	}
 
+	if (col < var_col_offset) {
+	  	if (role == Qt::BackgroundRole) return (Qt::lightGray);
+		return QVariant ();
+	}
+
 	// on a trailing col
 	if (col >= data_model->objects.size ()) {
 		if (role == Qt::BackgroundRole) return (Qt::gray);
@@ -488,6 +551,7 @@ Qt::ItemFlags RKVarEditMetaModel::flags (const QModelIndex& index) const {
 		return flags;
 	}
 
+	if (col < var_col_offset) return flags;
 	if (!data_model->edit_blocks) flags |= Qt::ItemIsEditable | Qt::ItemIsEnabled;
 	if ((col < data_model->objects.size ()) && (row < RowCount)) flags |= Qt::ItemIsSelectable;
 
@@ -505,6 +569,11 @@ bool RKVarEditMetaModel::setData (const QModelIndex& index, const QVariant& valu
 		return false;
 	}
 
+	if (col < var_col_offset) {
+		RK_ASSERT (false);
+		return false;
+	}
+
 	if (col >= data_model->objects.size ()) {		// trailing col
 		// somebody should add a column for us
 		data_model->doInsertColumns (data_model->objects.size (), 1);
@@ -623,11 +692,11 @@ void RKVarEditMetaModel::blankRange (const QItemSelectionRange& range) {
 
 	for (int col = left; col <= right; ++col) {
 		RKVariable* var = data_model->objects[col];
-		var->setSyncing (false);
+		var->lockSyncing (true);
 		for (int row = top; row <= bottom; ++row) {
 			setData (createIndex (row, col), QString (), Qt::EditRole);
 		}
-		var->setSyncing (true);
+		var->lockSyncing (false);
 	}
 }
 
@@ -656,13 +725,12 @@ void RKVarEditMetaModel::setTextMatrix (const QModelIndex& offset, const RKTextM
 	for (int col = left; col <= right; ++col) {
 		int trow = 0;
 		RKVariable* var = data_model->objects[col];
-		var->setSyncing (false);
+		var->lockSyncing (true);
 		for (int row = top; row <= bottom; ++row) {
 			setData (index (row, col), text.getText (trow, tcol), Qt::EditRole);
 			++trow;
 		}
-		var->syncDataToR ();
-		var->setSyncing (true);
+		var->lockSyncing (false);
 		++tcol;
 	}
 }
@@ -714,6 +782,9 @@ void RKVarEditDataFrameModel::init (RContainerObject* dataframe) {
 		RK_ASSERT (obj->isVariable ());
 		addObject (i, static_cast<RKVariable*> (obj));
 	}
+	rownames = dataframe->rowNames ();
+	addObject (0, rownames);
+	getMetaModel ()->var_col_offset = var_col_offset = 1;
 }
 
 RKVarEditDataFrameModel::~RKVarEditDataFrameModel () {
@@ -731,6 +802,7 @@ bool RKVarEditDataFrameModel::insertColumns (int column, int count, const QModel
 	}
 
 	if (column > trueCols ()) column = trueCols ();
+	if (column < var_col_offset) column = var_col_offset;
 	for (int col = column; col < (column + count); ++col) {
 		RObject *obj = dataframe->createPendingChild (dataframe->validizeName (QString ()), col);
 		RK_ASSERT (obj->isVariable ());
@@ -750,6 +822,11 @@ bool RKVarEditDataFrameModel::removeColumns (int column, int count, const QModel
 		return false;
 	}
 
+	if (column < var_col_offset) {
+		RK_ASSERT (false);
+		return false;
+	}
+
 	while ((column + count) > objects.size ()) --count;
 	for (int i = column + count - 1; i >= column; --i) {	// we start at the end so that the index remains valid
 		RKGlobals::tracker ()->removeObject (objects[i]);
@@ -779,7 +856,7 @@ void RKVarEditDataFrameModel::objectRemoved (RObject* object) {
 	RK_TRACE (EDITOR);
 
 	if (object == dataframe) {
-		while (!objects.isEmpty ()) RKVarEditModel::objectRemoved (objects[0]);
+		while (!objects.isEmpty ()) RKVarEditModel::objectRemoved (objects.last());		// NOTE: The rownames object (index position 0) must always go away last!
 		stopListenForObject (dataframe);
 		dataframe = 0;
 	}
@@ -798,7 +875,7 @@ void RKVarEditDataFrameModel::childAdded (int index, RObject* parent) {
 		RObject* child = dataframe->findChildByIndex (index);
 		RK_ASSERT (child);
 
-		if (child->isVariable ()) addObject (index, static_cast<RKVariable*> (child));
+		if (child->isVariable ()) addObject (index + var_col_offset, static_cast<RKVariable*> (child));
 		else RK_ASSERT (false);
 	}
 }
@@ -808,14 +885,14 @@ void RKVarEditDataFrameModel::childMoved (int old_index, int new_index, RObject*
 
 	if (parent == dataframe) {
 		RObject *child = dataframe->findChildByIndex (new_index);	// it's at the new position, already
-		RK_ASSERT (objects.size () > old_index);
-		RK_ASSERT (child == objects[old_index]);
+		RK_ASSERT (objects.size () > (old_index + var_col_offset));
+		RK_ASSERT (child == objects[old_index + var_col_offset]);
 		// if an object has changed position, there should be at least two objects left. Hence, the objectRemoved-call will never lead to editor destruction
-		RK_ASSERT (objects.size () >= 2);
+		RK_ASSERT (objects.size () >= (var_col_offset + 2));
 		objectRemoved (child);
 
 		RK_ASSERT (child->isVariable ());
-		addObject (new_index, static_cast<RKVariable*> (child));
+		addObject (new_index + var_col_offset, static_cast<RKVariable*> (child));
 	} else {
 		// even though we are listening for the child objects as well, we should see move notifications
 		// only for children of the parent.
@@ -839,8 +916,8 @@ void RKVarEditDataFrameModel::pushTable (RCommandChain *sync_chain) {
 	RK_ASSERT (objects.size ());
 	RKVariable* child = objects[0];
 	QString na_vector = "=as.numeric (rep (NA, " + QString::number (child->getLength ()) + "))";
-	for (int col=0; col < objects.size (); ++col) {
-		if (col != 0) command.append (", ");
+	for (int col=var_col_offset; col < objects.size (); ++col) {
+		if (col > var_col_offset) command.append (", ");
 		command.append (objects[col]->getShortName () + na_vector);
 	}
 	command.append (")");
