@@ -2,7 +2,7 @@
                           rkloadlibsdialog  -  description
                              -------------------
     begin                : Mon Sep 6 2004
-    copyright            : (C) 2004, 2006, 2007, 2008, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2008, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -170,8 +170,12 @@ bool RKLoadLibsDialog::installPackages (const QStringList &packages, const QStri
 	RK_TRACE (DIALOGS);
 
 	if (packages.isEmpty ()) return false;
-	QString command_string = "install.packages (pkgs=c (\"" + packages.join ("\", \"") + "\")" + ", lib=\"" + to_libloc + "\""; 
-	if (RKSettingsModuleRPackages::archivePackages ()) command_string += ", destdir=\"" + QDir (RKSettingsModuleGeneral::filesPath ()).filePath ("package_archive") + "\"";
+	QString command_string = "install.packages (pkgs=c (\"" + packages.join ("\", \"") + "\")" + ", lib=\"" + to_libloc + "\"";
+	QString downloaddir = QDir (RKSettingsModuleGeneral::filesPath ()).filePath ("package_archive");
+	if (RKSettingsModuleRPackages::archivePackages ()) {
+		QDir (RKSettingsModuleGeneral::filesPath ()).mkdir ("package_archive");
+		command_string += ", destdir=\"" + downloaddir + "\"";
+	}
 	if (install_dependencies) command_string += ", dependencies=TRUE";
 	command_string += ")\n";
 
@@ -189,7 +193,7 @@ bool RKLoadLibsDialog::installPackages (const QStringList &packages, const QStri
 			RK_ASSERT (false);
 #else
 			KUser user;
-			stream << QString ("system (\"chown ") + user.loginName() + ' ' + QDir (RKSettingsModuleGeneral::filesPath ()).filePath ("package_archive") + "/*\")\n";
+			stream << QString ("system (\"chown ") + user.loginName() + ' ' + downloaddir + "/*\")\n";
 #endif
 		}
 		stream << "q ()\n";
@@ -871,7 +875,7 @@ bool PackageInstallParamsWidget::checkWritable (bool *as_root) {
 		int res = KMessageBox::warningContinueCancel (this, message, mcaption, KGuiItem (i18n ("Attempt installation, anyway")));
 		if (res == KMessageBox::Continue) return true;
 #else
-		message.append (i18n ("If you are the adminitstrator of this machine, you can try to install the packages as root (you'll be prompted for the root password)."));
+		message.append (i18n ("If you are the administrator of this machine, you can try to install the packages as root (you'll be prompted for the root password)."));
 		int res = KMessageBox::warningContinueCancel (this, message, mcaption, KGuiItem (i18n ("Become root")));
 		if (res == KMessageBox::Continue) {
 			*as_root = true;
