@@ -2,7 +2,7 @@
                           rkstandardicons  -  description
                              -------------------
     begin                : Wed Oct 24 2007
-    copyright            : (C) 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -57,9 +57,20 @@ public:
 
 		ActionMoveLeft,
 		ActionMoveRight,
+		ActionMoveFirst,
+		ActionMoveLast,
 		ActionMoveUp,
 		ActionMoveDown,
 
+		ActionDocumentInfo,
+		ActionFlagGreen,
+		ActionSnapshot,
+		ActionListPlots,
+		ActionRemovePlot,
+		ActionWindowDuplicate,
+
+		ActionClear,
+
 		ActionDetachWindow,
 		ActionAttachWindow,
 
