@@ -34,8 +34,11 @@
 #include "../scriptbackends/phpbackend.h"
 #include "../scriptbackends/qtscriptbackend.h"
 #include "../scriptbackends/simplebackend.h"
+#include "../scriptbackends/rkcomponentscripting.h"
 #include "../misc/xmlhelper.h"
 #include "../settings/rksettingsmoduleplugins.h"
+#include "../windows/rkmdiwindow.h"
+#include "../windows/rkworkplace.h"
 
 // component widgets
 #include "rkvarselector.h"
@@ -64,6 +67,7 @@ RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget
 	RKStandardComponent::handle = handle;
 	command_chain = 0;
 	backend = 0;
+	scripting = 0;
 	gui = 0;
 	wizard = 0;
 	created = false;
@@ -71,6 +75,12 @@ RKStandardComponent::RKStandardComponent (RKComponent *parent_component, QWidget
 	addChild ("code", code = new RKComponentPropertyCode (this, true));		// do not change this name!
 	code->setInternal (true);
 
+	RKComponentPropertyBase *current_object_property = new RKComponentPropertyBase (this, false);
+	current_object_property->setInternal (true);
+	RKMDIWindow *w = RKWorkplace::mainWorkplace ()->activeWindow (RKMDIWindow::AnyWindowState);
+	if (w) current_object_property->setValue (w->globalContextProperty ("current_object"));
+	addChild ("current_object", current_object_property);
+
 	// open the main description file for parsing
 	XMLHelper* xml = XMLHelper::getStaticHelper ();
 	QDomElement doc_element = xml->openXMLFile (filename, DL_ERROR);
@@ -171,6 +181,16 @@ void RKStandardComponent::kill () {
 	deleteLater ();
 }
 
+RKComponentScriptingProxy* RKStandardComponent::scriptingProxy () {
+	RK_TRACE (PLUGIN);
+
+	if (!scripting) {
+		scripting = new RKComponentScriptingProxy (this);
+		connect (scripting, SIGNAL (haveError ()), this, SLOT (kill ()));
+	}
+	return scripting;
+}
+
 void RKStandardComponent::hide () {
 	RK_TRACE (PLUGIN);
 
@@ -640,6 +660,13 @@ void RKComponentBuilder::buildElement (const QDomElement &element, QWidget *pare
 			} else {
 				xml->displayError (&e, QString ("Could not embed component '%1'. Not found").arg (component_id), DL_ERROR);
 			}
+		} else if (e.tagName () == "scriptable") {
+			widget = new RKComponent (component (), parent_widget);
+			QVBoxLayout *layout = new QVBoxLayout (widget);
+			layout->setContentsMargins (0, 0, 0, 0);
+			KVBox *box = new KVBox (widget);
+			layout->addWidget (box);
+			component ()->scriptingProxy ()->addScriptableWidget (id, widget);
 		} else {
 			xml->displayError (&e, QString ("Invalid tagname '%1'").arg (e.tagName ()), DL_ERROR);
 		}
@@ -704,6 +731,13 @@ void RKComponentBuilder::parseLogic (const QDomElement &element) {
 		convert->setRequireTrue (xml->getBoolAttribute (*it, "require_true", false, DL_INFO));
 		component ()->addChild (id, convert);
 	}
+
+	QDomElement e = xml->getChildElement (element, "script", DL_INFO);
+	if (!e.isNull ()) {
+		QString file = xml->getStringAttribute (e, "file", QString (), DL_INFO);
+		QString inline_command = e.text ();
+		component ()->scriptingProxy ()->initialize (file, inline_command);
+	}
 }
 
 void RKComponentBuilder::addConnection (const QString &client_id, const QString &client_property, const QString &governor_id, const QString &governor_property, bool reconcile, const QDomElement &origin) {
