@@ -1,10 +1,8 @@
 // globals
 var q;
 
-
 function calculate () {
-	q = "c (" + preg_replace ("/[, ]+/", ", ", getValue ("q")) + ")";
-
+	q = "c (" + getValue ("q").replace (/[, ]+/g, ", ") + ")";
 
 	echo ('result <- (pexp (q = ' + q + ', rate = ' + getValue ("rate") + ', ' + getValue ("tail") + ', ' + getValue("logp") + '))\n');
 }
