@@ -124,7 +124,11 @@ bool repldll_last_parse_successful = false;
 
 SEXP RKWard_RData_Tag;
 QString *SEXPToStringList (SEXP from_exp, unsigned int *count);
+QString SEXPToString (SEXP from_exp);
 int *SEXPToIntArray (SEXP from_exp, unsigned int *count);
+int SEXPToInt (SEXP from_exp, int def_value = INT_MIN);
+SEXP parseCommand (const QString &command_qstring, REmbedInternal::RKWardRError *error);
+SEXP runCommandInternalBase (SEXP pr, REmbedInternal::RKWardRError *error);
 
 // ############## R Standard callback overrides BEGIN ####################
 void RSuicide (const char* message) {
@@ -138,34 +142,6 @@ void RSuicide (const char* message) {
 	Rf_error ("Backend dead");	// this jumps us out of the REPL.
 }
 
-void RShowMessage (const char* message) {
-	RK_TRACE (RBACKEND);
-
-	RCallbackArgs args;
-	args.type = RCallbackArgs::RShowMessage;
-	args.params["message"] = QVariant (message);
-	REmbedInternal::this_pointer->handleStandardCallback (&args);
-}
-
-// TODO: currently used on windows, only!
-/* FROM R_ext/RStartup.h: "Return value here is expected to be 1 for Yes, -1 for No and 0 for Cancel:
-   symbolic constants in graphapp.h" */
-int RAskYesNoCancel (const char* message) {
-	RK_TRACE (RBACKEND);
-
-	RCallbackArgs args;
-	args.type = RCallbackArgs::RShowMessage;
-	args.params["message"] = QVariant (message);
-	args.params["askync"] = QVariant (true);
-
-	REmbedInternal::this_pointer->handleStandardCallback (&args);
-
-	QString ret = args.params["result"].toString ();
-	if (ret == "yes") return 1;
-	if (ret == "no") return -1;
-	return 0;
-}
-
 int RReadConsole (const char* prompt, unsigned char* buf, int buflen, int hist) {
 	RK_TRACE (RBACKEND);
 
@@ -317,14 +293,12 @@ SEXP doShowEditFiles (SEXP files, SEXP titles, SEXP wtitle, SEXP del, RCallbackA
 	RK_TRACE (RBACKEND);
 
 	// this function would be much shorter, if SEXPToStringList would simply return a QStringList...
-	unsigned int files_count, titles_count, wtitle_count, del_count;
+	unsigned int files_count, titles_count;
 	QString *file_strings = SEXPToStringList (files, &files_count);
 	QString *title_strings = SEXPToStringList (titles, &titles_count);
-	QString *wtitle_strings = SEXPToStringList (wtitle, &wtitle_count);
-	int *del_bools = SEXPToIntArray (del, &del_count);
+	QString wtitle_string = SEXPToString (wtitle);
+	bool del_files = SEXPToInt (del, 0) != 0;
 
-	RK_ASSERT (wtitle_count <= 1);
-	RK_ASSERT (del_count <= 1);
 	RK_ASSERT (files_count == titles_count);
 	RK_ASSERT (files_count >= 1);
 
@@ -336,17 +310,11 @@ SEXP doShowEditFiles (SEXP files, SEXP titles, SEXP wtitle, SEXP del, RCallbackA
 		files_list.append (file_strings[i]);
 		titles_list.append (title_strings[i]);
 	}
-	QString wtitle_string;
-	if (wtitle_count) wtitle_string = wtitle_strings[0];
-	bool del_files = false;
-	if (del_count) del_files = (del_bools[0] != 0);
 
 	REditFilesHelper (files_list, titles_list, wtitle_string, edit, del_files);
 
 	delete [] file_strings;
 	delete [] title_strings;
-	delete [] wtitle_strings;
-	delete [] del_bools;
 
 	return (R_NilValue);
 }
@@ -378,6 +346,51 @@ int RShowFiles (int nfile, const char **file, const char **headers, const char *
 	return 1;
 }
 
+/* FROM R_ext/RStartup.h: "Return value here is expected to be 1 for Yes, -1 for No and 0 for Cancel:
+   symbolic constants in graphapp.h" */
+int doDialogHelper (QString caption, QString message, QString button_yes, QString button_no, QString button_cancel, bool wait) {
+	RK_TRACE (RBACKEND);
+
+	RCallbackArgs args;
+	args.type = RCallbackArgs::RShowMessage;
+	args.params["caption"] = QVariant (caption);
+	args.params["message"] = QVariant (message);
+	args.params["button_yes"] = QVariant (button_yes);
+	args.params["button_no"] = QVariant (button_no);
+	args.params["button_cancel"] = QVariant (button_cancel);
+	if (wait) args.params["wait"] = "1";
+
+	REmbedInternal::this_pointer->handleStandardCallback (&args);
+
+	QString ret = args.params["result"].toString ();
+	if (ret == "yes") return 1;
+	if (ret == "no") return -1;
+	return 0;
+}
+
+SEXP doDialog (SEXP caption, SEXP message, SEXP button_yes, SEXP button_no, SEXP button_cancel, SEXP wait) {
+	RK_TRACE (RBACKEND);
+
+	int result = doDialogHelper (SEXPToString (caption), SEXPToString (message), SEXPToString (button_yes), SEXPToString (button_no), SEXPToString (button_cancel), SEXPToInt (wait));
+
+	SEXP ret = Rf_allocVector(INTSXP, 1);
+	INTEGER (ret)[0] = result;
+	return ret;
+}
+
+void RShowMessage (const char* message) {
+	RK_TRACE (RBACKEND);
+
+	doDialogHelper (i18n ("Message from the R backend"), message, "ok", QString (), QString (), true);
+}
+
+// TODO: currently used on windows, only!
+int RAskYesNoCancel (const char* message) {
+	RK_TRACE (RBACKEND);
+
+	return doDialogHelper (i18n ("Question from the R backend"), message, "yes", "no", "cancel", true);
+}
+
 void RBusy (int busy) {
 	RK_TRACE (RBACKEND);
 
@@ -519,6 +532,20 @@ void REmbedInternal::processX11Events () {
 	R_ToplevelExec (processX11EventsWorker, 0);
 }
 
+/** converts SEXP to strings, and returns the first string (or QString(), if SEXP contains no strings) */
+QString SEXPToString (SEXP from_exp) {
+	RK_TRACE (RBACKEND);
+
+	QString ret;
+
+	unsigned int count;
+	QString *list = SEXPToStringList (from_exp, &count);
+
+	if (count >= 1) ret = list[0];
+	delete [] list;
+	return ret;
+}
+
 QString *SEXPToStringList (SEXP from_exp, unsigned int *count) {
 	RK_TRACE (RBACKEND);
 
@@ -586,6 +613,19 @@ int *SEXPToIntArray (SEXP from_exp, unsigned int *count) {
 	return integers;
 }
 
+/** converts SEXP to integers, and returns the first int (def_value, if SEXP contains no ints) */
+int SEXPToInt (SEXP from_exp, int def_value) {
+	RK_TRACE (RBACKEND);
+
+	int ret = def_value;
+	unsigned int count;
+	int *integers = SEXPToIntArray (from_exp, &count);
+	if (count >= 1) ret = integers[0];
+	delete [] integers;
+
+	return ret;
+}
+
 double *SEXPToRealArray (SEXP from_exp, unsigned int *count) {
 	RK_TRACE (RBACKEND);
 
@@ -826,6 +866,7 @@ bool REmbedInternal::startR (int argc, char** argv, bool stack_check) {
 		{ "rk.copy.no.eval", (DL_FUNC) &doCopyNoEval, 3 },
 		{ "rk.edit.files", (DL_FUNC) &doEditFiles, 3 },
 		{ "rk.show.files", (DL_FUNC) &doShowFiles, 4 },
+		{ "rk.dialog", (DL_FUNC) &doDialog, 6 },
 		{ "rk.update.locale", (DL_FUNC) &doUpdateLocale, 0 },
 		{ "rk.locale.name", (DL_FUNC) &doLocaleName, 0 },
 		{ 0, 0, 0 }
@@ -834,6 +875,15 @@ bool REmbedInternal::startR (int argc, char** argv, bool stack_check) {
 
 	connectCallbacks();
 
+	// get info on R runtime version
+	REmbedInternal::RKWardRError error;
+	unsigned int count;
+	int *dummy = getCommandAsIntVector ("as.numeric (R.version$major) * 1000 + as.numeric (R.version$minor) * 10", &count, &error);
+	RK_ASSERT ((error == REmbedInternal::NoError) && (count == 1));
+	if (count) r_version = dummy[0];
+	else r_version = 0;
+	delete [] dummy;
+
 	return true;
 }
 
@@ -972,6 +1022,9 @@ void runUserCommandInternal (void *) {
 	} while (((repldll_result = R_ReplDLLdo1 ()) == 2) && (!repldll_buffer_transfer_finished));	// keep iterating while the statement is incomplete, and we still have more in the buffer to transfer
 	//Rprintf ("iteration complete, status: %d\n", repldll_result);
 	PROTECT (R_LastvalueSymbol);		// why do we need this? No idea, but R_ToplevelExec tries to unprotect something
+	if (REmbedInternal::this_pointer->RRuntimeIsVersion (2, 11, 9)) {
+		PROTECT (R_LastvalueSymbol);		// ... and with R 2.12.0 it tries to unprotect two things
+	}
 }
 
 void REmbedInternal::runCommandInternal (const QString &command_qstring, RKWardRError *error, bool print_result) {
