@@ -221,7 +221,8 @@ void RInterface::customEvent (QEvent *e) {
 			<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://p.sf.net/rkward/compiling\">http://p.sf.net/rkward/compiling</a>.</p>\n"));
 		}
 		if (err & RThread::SinkFail) {
-			message.append (i18n ("<p>\t-There was a problem opening the files needed for communication with R. Most likely this is due to an incorrect setting for the location of these files. Check whether you have correctly configured the location of the log-files (Settings->Configure Settings->Logfiles) and restart RKWard.</p>\n"));
+			message.append (i18n ("<p>\t-There was a problem setting up the communication with R. Most likely this is due to an incorrect version of the 'rkward' R-library or failure to find that at all. This indicates a broken installation.</p>\
+			<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://p.sf.net/rkward/compiling\">http://p.sf.net/rkward/compiling</a>.</p></p>\n"));
 		}
 		if (err & RThread::OtherFail) {
 			message.append (i18n ("<p>\t-An unspecified error occurred that is not yet handled by RKWard. Likely RKWard will not function properly. Please check your setup.</p>\n"));
@@ -383,6 +384,14 @@ void RInterface::processREvalRequest (REvalRequest *request) {
 			window_catcher->stop (QString (request->call[1]).toInt ());
 			MUTEX_UNLOCK;
 		}
+	} else if (call == "updateDeviceHistory") {
+		if (request->call.count () >= 2) {
+			window_catcher->updateHistory (request->call.mid (1));
+		}
+	} else if (call == "killDevice") {
+		if (request->call.count () >= 2) {
+			window_catcher->killDevice (request->call[1].toInt ());
+		}
 #endif // DISABLE_RKWINDOWCATCHER
 	} else if (call == "wdChange") {
 		RKWardMainWindow::getMain ()->updateCWD ();
@@ -410,6 +419,13 @@ void RInterface::processREvalRequest (REvalRequest *request) {
 		} else {
 			RK_ASSERT (false);
 		}
+	} else if (call == "listPlugins") {
+		if (request->call.count () == 1) {
+			QStringList list = RKComponentMap::getMap ()->allComponentIds ();
+			issueCommand (".rk.set.reply (c (\"" + list.join ("\", \"") + "\"))\n", RCommand::App | RCommand::Sync, QString::null, 0, 0, request->in_chain);
+		} else {
+			RK_ASSERT (false);
+		}
 	} else if (call == "showHTML") {
 		if (request->call.count () == 2) {
 			RKWorkplace::mainWorkplace ()->openHelpWindow (request->call[1]);
@@ -473,14 +489,47 @@ void RInterface::processRCallbackRequest (RCallbackArgs *args) {
 	RCallbackArgs::RCallbackType type = args->type;
 
 	if (type == RCallbackArgs::RShowMessage) {
-		if (args->params.value ("askync").toBool ()) {
-			int res = KMessageBox::questionYesNoCancel (0, args->params["message"].toString (), i18n ("Question from the R backend"));
-			if (res == KMessageBox::Yes) args->params["result"] = "yes";
-			else if (res == KMessageBox::No) args->params["result"] = "no";
-			// else: cancel
-		} else {
-			KMessageBox::information (0, args->params["message"].toString (), i18n ("Message from the R backend"));
+		QString caption = args->params["caption"].toString ();
+		QString message = args->params["message"].toString ();
+		QString button_yes = args->params["button_yes"].toString ();;
+		QString button_no = args->params["button_no"].toString ();;
+		QString button_cancel = args->params["button_cancel"].toString ();;
+
+		KGuiItem button_yes_item = KStandardGuiItem::yes ();
+		if (button_yes != "yes") button_yes_item.setText (button_yes);
+		KGuiItem button_no_item = KStandardGuiItem::no ();
+		if (button_no != "no") button_no_item.setText (button_no);
+		KGuiItem button_cancel_item = KStandardGuiItem::cancel ();
+		if (button_cancel != "cancel") button_cancel_item.setText (button_cancel);
+
+		bool shown = false;
+		KMessageBox::DialogType dialog_type = KMessageBox::QuestionYesNoCancel;
+		if (button_cancel.isEmpty ()) dialog_type = KMessageBox::QuestionYesNo;
+		if (button_no.isEmpty () && button_cancel.isEmpty ()) {
+			dialog_type = KMessageBox::Information;
+			if (args->params["wait"].toString () != "1") {	// non-modal dialogs are not supported out of the box by KMessageBox;
+				KDialog* dialog = new KDialog ();
+				KMessageBox::createKMessageBox (dialog, QMessageBox::Information, message, QStringList (), QString (), 0, KMessageBox::Notify | KMessageBox::NoExec);
+				dialog->setWindowTitle (caption);
+				dialog->setAttribute (Qt::WA_DeleteOnClose);
+				dialog->setButtons (KDialog::Ok);
+				dialog->show();
+				shown = true;
+			}
 		}
+
+		int result = KMessageBox::Ok;
+		if (!shown) {
+			result = KMessageBox::messageBox (0, dialog_type, message, caption, button_yes_item, button_no_item, button_cancel_item);
+		}
+
+		QString result_string;
+		if ((result == KMessageBox::Yes) || (result == KMessageBox::Ok)) result_string = "yes";
+		else if (result == KMessageBox::No) result_string = "no";
+		else if (result == KMessageBox::Cancel) result_string = "cancel";
+		else RK_ASSERT (false);
+
+		args->params["result"] = result_string;
 	} else if (type == RCallbackArgs::RReadLine) {
 		QString result;
 
