@@ -144,52 +144,6 @@
 	error ("Could not find column with given name")
 }
 
-# Requests a graph to be written.
-rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOption ("rk.graphics.width"), height=getOption ("rk.graphics.height"), quality, ...) 
-{
-	if (!is.numeric (width)) width <- 480
-	if (!is.numeric (height)) height <- 480
-	if (is.null (device.type)) device.type <- "PNG"	# default behavior is PNG for now
-
-	ret <- NULL
-	if (device.type == "PNG") {
-		filename <- rk.get.tempfile.name(prefix = "graph", extension = ".png")
-		ret <- png(filename = file.path(filename), width = width, height = height, ...)
-		.rk.cat.output(paste("<img src=\"", filename, "\" width=\"", width, 
-			"\" height=\"", height, "\"><br>", sep = ""))
-	} else if (device.type == "JPG") {
-		if (missing (quality)) {
-			quality = getOption ("rk.graphics.jpg.quality")		# COMPAT: getOption (x, *default*) not yet available in R 2.9
-			if (is.null (quality)) quality = 75
-		}
-		filename <- rk.get.tempfile.name(prefix = "graph", extension = ".jpg")
-		ret <- jpeg(filename = file.path(filename), width = width, height = height, "quality"=quality, ...)
-		.rk.cat.output(paste("<img src=\"", filename, "\" width=\"", width, 
-			"\" height=\"", height, "\"><br>", sep = ""))
-	} else if (device.type == "SVG") {
-		if (!capabilities ("cairo")) {	# cairo support is not always compiled in
-			require (cairoDevice)
-			svg <- Cairo_svg
-		}
-		filename <- rk.get.tempfile.name(prefix = "graph", extension = ".svg")
-		ret <- svg(filename = file.path(filename), ...)
-		.rk.cat.output(paste("<object data=\"", filename, "\" type=\"image/svg+xml\" width=\"", width, 
-			"\" height=\"", height, "\">\n", sep = ""))
-		.rk.cat.output(paste("<param name=\"src\" value=\"", filename, "\">\n", sep = ""))
-		.rk.cat.output(paste("This browser appears incapable of displaying SVG object. The SVG source is at:", filename))
-		.rk.cat.output("</object>")
-	} else {
-		stop (paste ("Device type \"", device.type, "\" is unknown to RKWard", sep=""))
-	}
-
-	invisible (ret)
-}
-
-"rk.graph.off" <- function(){
-	.rk.cat.output ("\n")	# so the output will be auto-refreshed
-	dev.off()
-}
-
 "rk.print" <- function(x,...) {
 	htmlfile <- rk.get.output.html.file()
 	if(require("R2HTML")==TRUE) {
@@ -314,7 +268,7 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 }
 
 "rk.make.repos.string" <- function () {
-	x <- options ("repos")$repos
+	x <- getOption ("repos")
 	len <- length (x)
 	ret <- sprintf ("c (")
 	first <- TRUE
@@ -417,6 +371,12 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	invisible (TRUE)
 }
 
+# list all available plugins in RKWard; this is a companion function for rk.call.plugin:
+# the output provides possible strings for "plugin" argument in rk.call.plugin
+rk.list.plugins <- function () {
+	.rk.do.call ("listPlugins")
+}
+
 # a wrapper around chooseCRANmirror() without changing options ("repos"), permanently
 "rk.select.CRAN.mirror" <- function () {
 	old_repos <- getOption("repos")
@@ -463,3 +423,16 @@ rk.graph.on <- function (device.type=getOption ("rk.graphics.type"), width=getOp
 	.rk.do.call ("select.list", params)
 }
 
+"rk.show.message" <- function (message, caption = "Information", wait=TRUE) {
+	.Call ("rk.dialog", caption, message, "ok", "", "", isTRUE (wait))
+	invisible (TRUE)
+}
+
+# to disable a button, set it to ""
+"rk.show.question" <- function (message, caption = "Question", button.yes = "yes", button.no = "no", button.cancel = "cancel") {
+	res <- .Call ("rk.dialog", caption, message, button.yes, button.no, button.cancel, TRUE)
+	if (res > 0) return (TRUE)
+	else if (res < 0) return (FALSE)
+	else return (NULL)	# cancelled
+}
+
