@@ -46,11 +46,15 @@
 #include <klibloader.h>
 #include <kactioncollection.h>
 #include <kactionmenu.h>
+#include <ktemporaryfile.h>
+#include <kio/deletejob.h>
+#include <kio/job.h>
 
 #include "../misc/rkcommonfunctions.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/rkstandardactions.h"
 #include "../misc/rkxmlguisyncer.h"
+#include "../misc/rkjobsequence.h"
 #include "../core/robjectlist.h"
 #include "../settings/rksettings.h"
 #include "../settings/rksettingsmodulecommandeditor.h"
@@ -99,6 +103,7 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 	part->insertChildClient (m_view);
 	setPart (part);
 	fixupPartGUI ();
+	setMetaInfo (i18n ("Script Editor"), QString (), RKSettings::PageCommandEditor);
 	initializeActions (part->actionCollection ());
 	initializeActivationSignals ();
 	RKXMLGUISyncer::self()->registerChangeListener (m_view, this, SLOT (fixupPartGUI()));
@@ -108,8 +113,10 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 	layout->addWidget(m_view);
 
 	connect (m_doc, SIGNAL (documentUrlChanged (KTextEditor::Document*)), this, SLOT (updateCaption (KTextEditor::Document*)));
-	connect (m_doc, SIGNAL (modifiedChanged (KTextEditor::Document*)), this, SLOT (updateCaption (KTextEditor::Document*)));		// of course most of the time this causes a redundant call to updateCaption. Not if a modification is undone, however.
+	connect (m_doc, SIGNAL (modifiedChanged (KTextEditor::Document*)), this, SLOT (updateCaption(KTextEditor::Document*)));                // of course most of the time this causes a redundant call to updateCaption. Not if a modification is undone, however.
+	connect (m_doc, SIGNAL (modifiedChanged (KTextEditor::Document*)), this, SLOT (autoSaveHandlerModifiedChanged()));
 	connect (m_doc, SIGNAL (textChanged (KTextEditor::Document*)), this, SLOT (tryCompletionProxy (KTextEditor::Document*)));
+	connect (m_doc, SIGNAL (textChanged (KTextEditor::Document*)), this, SLOT (autoSaveHandlerTextChanged()));
 	connect (m_view, SIGNAL (selectionChanged(KTextEditor::View*)), this, SLOT (selectionChanged(KTextEditor::View*)));
 	// somehow the katepart loses the context menu each time it loses focus
 	connect (m_view, SIGNAL (focusIn(KTextEditor::View*)), this, SLOT (focusIn(KTextEditor::View*)));
@@ -132,10 +139,17 @@ RKCommandEditorWindow::RKCommandEditorWindow (QWidget *parent, bool use_r_highli
 		hinter = new RKFunctionArgHinter (this, m_view);
 	}
 
+#if KDE_IS_VERSION(4,5,0)
+	smart_iface = qobject_cast<KTextEditor::MovingInterface*> (m_doc);
+#else
 	smart_iface = qobject_cast<KTextEditor::SmartInterface*> (m_doc);
+#endif
 	initBlocks ();
 	RK_ASSERT (smart_iface);
 
+	autosave_timer = new QTimer (this);
+	connect (autosave_timer, SIGNAL (timeout()), this, SLOT (doAutoSave()));
+
 	updateCaption ();	// initialize
 	QTimer::singleShot (0, this, SLOT (setPopupMenu ()));
 }
@@ -183,13 +197,11 @@ void RKCommandEditorWindow::initializeActions (KActionCollection* ac) {
 	action_setwd_to_script->setHelpText (i18n ("Change the working directory to the directory of this script"));
 #endif
 	action_setwd_to_script->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionCDToScript));
-
-	KAction* action_configure = ac->addAction ("configure_commandeditor", this, SLOT (configure()));
-	action_configure->setText (i18n ("Configure Script Editor"));
 }
 
 void RKCommandEditorWindow::initBlocks () {
 	RK_TRACE (COMMANDEDITOR);
+	if (!smart_iface) return;	// may happen in KDE => 4.6 if compiled with KDE <= 4.4
 	RK_ASSERT (block_records.isEmpty ());
 
 	KActionCollection* ac = getPart ()->actionCollection ();
@@ -242,6 +254,10 @@ void RKCommandEditorWindow::initBlocks () {
 		record.run->setData (i);
 		actionmenu_run_block->addAction (record.run);
 
+		// these two not strictly needed due to removeBlock(), below. Silences a GCC warning, however.
+		record.range = 0;
+		record.active = false;
+
 		block_records.append (record);
 		removeBlock (i, true);	// initialize to empty
 	}
@@ -331,6 +347,104 @@ bool RKCommandEditorWindow::openURL (const KUrl &url, const QString& encoding, b
 	return false;
 }
 
+void RKCommandEditorWindow::autoSaveHandlerModifiedChanged () {
+	RK_TRACE (COMMANDEDITOR);
+
+	if (!isModified ()) {
+		autosave_timer->stop ();
+
+		if (RKSettingsModuleCommandEditor::autosaveKeep ()) return;
+		if (!previous_autosave_url.isValid ()) return;
+		if (previous_autosave_url.isLocalFile ()) {
+			QFile::remove (previous_autosave_url.toLocalFile ());
+		} else {
+			RKJobSequence* dummy = new RKJobSequence ();
+			dummy->addJob (KIO::del (previous_autosave_url));
+			connect (dummy, SIGNAL (finished(RKJobSequence*)), this, SLOT (autoSaveHandlerJobFinished(RKJobSequence*)));
+			dummy->start ();
+		}
+		previous_autosave_url.clear ();
+	}
+}
+
+void RKCommandEditorWindow::autoSaveHandlerTextChanged () {
+	RK_TRACE (COMMANDEDITOR);
+
+	if (!isModified ()) return;		// may happen after load or undo
+	if (!RKSettingsModuleCommandEditor::autosaveEnabled ()) return;
+	if (!autosave_timer->isActive ()) {
+		autosave_timer->start (RKSettingsModuleCommandEditor::autosaveInterval () * 60 * 1000);
+	}
+}
+
+void RKCommandEditorWindow::doAutoSave () {
+	RK_TRACE (COMMANDEDITOR);
+	RK_ASSERT (isModified ());
+
+	KTemporaryFile save;
+	save.setSuffix (RKSettingsModuleCommandEditor::autosaveSuffix ());
+	RK_ASSERT (save.open ());
+	QTextStream out (&save);
+	out.setCodec ("UTF-8");		// make sure that all characters can be saved, without nagging the user
+	out << m_doc->text ();
+	save.close ();
+	save.setAutoRemove (false);
+
+	RKJobSequence* alljobs = new RKJobSequence ();
+	// The KJob-Handling below seems to be a bit error-prone, at least for the file-protocol on Windows.
+	// Thus, for the simple case of local files, we use QFile, instead.
+	connect (alljobs, SIGNAL (finished(RKJobSequence*)), this, SLOT (autoSaveHandlerJobFinished(RKJobSequence*)));
+	// backup the old autosave file in case something goes wrong during pushing the new one
+	KUrl backup_autosave_url;
+	if (previous_autosave_url.isValid ()) {
+		backup_autosave_url = previous_autosave_url;
+		backup_autosave_url.setFileName (backup_autosave_url.fileName () + "~");
+		if (previous_autosave_url.isLocalFile ()) {
+			QFile::remove (backup_autosave_url.toLocalFile ());
+			QFile::copy (previous_autosave_url.toLocalFile (), backup_autosave_url.toLocalFile ());
+		} else {
+			alljobs->addJob (KIO::file_move (previous_autosave_url, backup_autosave_url, -1, KIO::HideProgressInfo | KIO::Overwrite));
+		}
+	}
+	
+	// push the newly written file
+	if (url ().isValid ()) {
+		KUrl autosave_url = url ();
+		autosave_url.setFileName (autosave_url.fileName () + RKSettingsModuleCommandEditor::autosaveSuffix ());
+		if (autosave_url.isLocalFile ()) {
+			QFile::remove (autosave_url.toLocalFile ());
+			save.copy (autosave_url.toLocalFile ());
+			save.remove ();
+		} else {
+			alljobs->addJob (KIO::file_move (KUrl::fromLocalFile (save.fileName ()), autosave_url, -1, KIO::HideProgressInfo | KIO::Overwrite));
+		}
+		previous_autosave_url = autosave_url;
+	} else {		// i.e., the document is still "Untitled"
+		previous_autosave_url = KUrl::fromLocalFile (save.fileName ());
+	}
+
+	// remove the backup
+	if (backup_autosave_url.isValid ()) {
+		if (backup_autosave_url.isLocalFile ()) {
+			QFile::remove (backup_autosave_url.toLocalFile ());
+		} else {
+			alljobs->addJob (KIO::del (backup_autosave_url, KIO::HideProgressInfo));
+		}
+	}
+	alljobs->start ();
+
+	// do not create any more autosaves until the text is changed, again
+	autosave_timer->stop ();
+}
+
+void RKCommandEditorWindow::autoSaveHandlerJobFinished (RKJobSequence* seq) {
+	RK_TRACE (COMMANDEDITOR);
+
+	if (seq->hadError ()) {
+		KMessageBox::detailedError (this, i18n ("An error occurred while trying to create an autosave of the script file '%1':", url ().url ()), "- " + seq->errors ().join ("\n- "));
+	}
+}
+
 KUrl RKCommandEditorWindow::url () {
 //	RK_TRACE (COMMANDEDITOR);
 	return (m_doc->url ());
@@ -557,7 +671,11 @@ void RKCommandEditorWindow::clearUnusedBlocks () {
 	for (int i = 0; i < block_records.size (); ++i) {
 		if (block_records[i].active) {
 // TODO: do we need to check whether the range was deleted? Does the katepart do such evil things?
+#if KDE_IS_VERSION(4,5,0)
+			if (block_records[i].range->isEmpty ()) {
+#else
 			if (!block_records[i].range->isValid () || block_records[i].range->isEmpty ()) {
+#endif
 				removeBlock (i, true);
 			}
 		}
@@ -566,13 +684,19 @@ void RKCommandEditorWindow::clearUnusedBlocks () {
 
 void RKCommandEditorWindow::addBlock (int index, const KTextEditor::Range& range) {
 	RK_TRACE (COMMANDEDITOR);
+	if (!smart_iface) return;	// may happen in KDE => 4.6 if compiled with KDE <= 4.4
 	RK_ASSERT ((index >= 0) && (index < block_records.size ()));
 
 	clearUnusedBlocks ();
 	removeBlock (index);
 
+#if KDE_IS_VERSION(4,5,0)
+	KTextEditor::MovingRange* srange = smart_iface->newMovingRange (range);
+	srange->setInsertBehaviors (KTextEditor::MovingRange::ExpandRight);
+#else
 	KTextEditor::SmartRange* srange = smart_iface->newSmartRange (range);
 	srange->setInsertBehavior (KTextEditor::SmartRange::ExpandRight);
+#endif
 
 	QString actiontext = i18n ("%1 (Active)", index + 1);
 	block_records[index].range = srange;
@@ -584,15 +708,20 @@ void RKCommandEditorWindow::addBlock (int index, const KTextEditor::Range& range
 	block_records[index].run->setText (actiontext);
 	block_records[index].run->setEnabled (true);
 
+#if !KDE_IS_VERSION(4,5,0)
 	smart_iface->addHighlightToView (m_view, srange);
+#endif
 }
 
 void RKCommandEditorWindow::removeBlock (int index, bool was_deleted) {
 	RK_TRACE (COMMANDEDITOR);
+	if (!smart_iface) return;	// may happen in KDE => 4.6 if compiled with KDE <= 4.4
 	RK_ASSERT ((index >= 0) && (index < block_records.size ()));
 
 	if (!was_deleted) {
+#if !KDE_IS_VERSION(4,5,0)
 		smart_iface->removeHighlightFromView (m_view, block_records[index].range);
+#endif
 		delete (block_records[index].range);
 	}
 
@@ -619,12 +748,6 @@ void RKCommandEditorWindow::selectionChanged (KTextEditor::View* view) {
 	}
 }
 
-void RKCommandEditorWindow::configure () {
-	RK_TRACE (COMMANDEDITOR);
-
-	RKSettings::configureSettings (RKSettings::PageCommandEditor, this);
-}
-
 //////////////////////// RKFunctionArgHinter //////////////////////////////
 
 #include "../core/rfunctionobject.h"
@@ -662,6 +785,8 @@ RKFunctionArgHinter::~RKFunctionArgHinter () {
 void RKFunctionArgHinter::tryArgHint () {
 	RK_TRACE (COMMANDEDITOR);
 
+	if (!RKSettingsModuleCommandEditor::argHintingEnabled ()) return;
+
 	// do this in the next event cycle to make sure any inserted characters have truly been inserted
 	QTimer::singleShot (0, this, SLOT (tryArgHintNow ()));
 }
