@@ -22,12 +22,18 @@
 #include <QTimer>
 #include <QString>
 
+#include <kdeversion.h>
 #include <ktexteditor/view.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/codecompletionmodel.h>
 #include <ktexteditor/codecompletioninterface.h>
-#include <ktexteditor/smartrange.h>
-#include <ktexteditor/smartinterface.h>
+#if KDE_IS_VERSION(4,5,0)
+#	include <ktexteditor/movingrange.h>
+#	include <ktexteditor/movinginterface.h>
+#else
+#	include <ktexteditor/smartrange.h>
+#	include <ktexteditor/smartinterface.h>
+#endif
 #include <kurl.h>
 
 #include "../windows/rkmdiwindow.h"
@@ -116,6 +122,7 @@ private:
 };
 
 class QTimer;
+class RKJobSequence;
 
 /**
 	\brief Provides an editor window for R-commands, as well as a text-editor window in general.
@@ -176,8 +183,6 @@ public slots:
 	void runLine ();
 /** run the entire script */
 	void runAll ();
-/** invoke the settings page for the command editor */
-	void configure ();
 
 /** selection has changed. Enable / disable actions accordingly */
 	void selectionChanged (KTextEditor::View* view);
@@ -199,11 +204,23 @@ private slots:
 /** run a block */
 	void runBlock ();
 	void clearUnusedBlocks ();
+/** creates an autosave file */
+	void doAutoSave ();
+/** handler to control when autosaves should be created */
+	void autoSaveHandlerModifiedChanged ();
+/** handler to control when autosaves should be created */
+	void autoSaveHandlerTextChanged ();
+/** handle any errors during auto-saving */
+	void autoSaveHandlerJobFinished (RKJobSequence* seq);
 private:
 	KTextEditor::Document *m_doc;
 	KTextEditor::View *m_view;
 	KTextEditor::CodeCompletionInterface *cc_iface;
+#if KDE_IS_VERSION(4,5,0)
+	KTextEditor::MovingInterface *smart_iface;
+#else
 	KTextEditor::SmartInterface *smart_iface;
+#endif
 	RKFunctionArgHinter *hinter;
 	RKCodeCompletionModel *completion_model;
 
@@ -214,7 +231,11 @@ private:
 	void initializeActions (KActionCollection* ac);
 
 	struct BlockRecord {
+#if KDE_IS_VERSION(4,5,0)
+		KTextEditor::MovingRange* range;
+#else
 		KTextEditor::SmartRange* range;
+#endif
 		bool active;
 		KTextEditor::Attribute::Ptr attribute;
 		KAction* mark;
@@ -237,6 +258,9 @@ private:
 	KAction* action_setwd_to_script;
 
 	KAction* action_help_function;
+
+	KUrl previous_autosave_url;
+	QTimer* autosave_timer;
 };
 
 #endif
