@@ -2,7 +2,7 @@
                           rkhelpsearchwindow  -  description
                              -------------------
     begin                : Fri Feb 25 2005
-    copyright            : (C) 2005, 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2005, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -30,7 +30,7 @@ class QCheckBox;
 class QPushButton;
 class RKHelpSearchResultsModel;
 class QTreeView;
-
+class QSortFilterProxyModel;
 class RCommandChain;
 
 /** Provides a UI interface for help-search.
@@ -64,12 +64,13 @@ private:
 	QPushButton* findButton;
 	QTreeView* results_view;
 	RKHelpSearchResultsModel* results;
+	QSortFilterProxyModel* proxy_model;
 
 friend class RKWardMainWindow;
 	static RKHelpSearchWindow *main_help_search;
 };
 
-/** An item model meant for use by RKHelpSearchWindow. Since it is fairly specialized, it is unlikely to be of any use in any other context.
+/** An item model meant for use by RKHelpSearchWindow. Since it is fairly specialized, it is unlikely to be of any use in any other context. NOTE: This class is pretty useless, really, we should just switch to a QTree/TableWidget with predefined model, whenever we need to make the next big change to the RKHelpSearchWindow.
 @author Thomas Friedrichsmeier */
 class RKHelpSearchResultsModel : public QAbstractTableModel {
 public:
