@@ -2,7 +2,7 @@
                           rkmdiwindow  -  description
                              -------------------
     begin                : Tue Sep 26 2006
-    copyright            : (C) 2006, 2007, 2008, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2006, 2007, 2008, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -18,11 +18,13 @@
 #ifndef RKMDIWINDOW_H
 #define RKMDIWINDOW_H
 
-#include <qwidget.h>
 #include <QFrame>
+#include <QMap>
 
 #include <kparts/part.h>
 
+#include "../settings/rksettings.h"
+
 class QEvent;
 class QPaintEvent;
 class RKWorkplace;
@@ -106,20 +108,28 @@ public:
 	bool isActive ();
 /** Returns a pointer to an action collection suitable to place RKStandardAction in. This collection (and the corresponding KXMLGUIClient) is created on the fly. */
 	KActionCollection *standardActionCollection ();
+/** plugin-accessible properties of this object in the global context. Currently used only by RKEditorDataFrame to give information on the currently active data.frame. NOTE: ATM, you cannot set arbitrary properties. Only those supported in RKStandardComponent will have an effect. */
+	QString globalContextProperty (const QString& property) { return global_context_properties.value (property); };
 signals:
 /** This signal is emitted, whenever the window caption was changed.
 @param RKMDIWindow* a pointer to this window */
 	void captionChanged (RKMDIWindow *);
 /** This signal is emitted, when the window was activated *with* focus */
 	void windowActivated (RKMDIWindow *);
+protected slots:
+	void showWindowHelp ();
+	void showWindowSettings ();
 protected:
 	void setPart (KParts::Part *p) { part = p; };
+	void setMetaInfo (const QString& generic_window_name, const QString& help_url, RKSettings::SettingsPage settings_page=RKSettings::NoPage);
 	void initializeActivationSignals ();
 	void paintEvent (QPaintEvent *e);
 	void windowActivationChange (bool);
 
 /** reimplemented from QWidget to emulate focus-follows-mouse behavior */
 	void enterEvent (QEvent *event);
+/** @see globalContextProperty() */
+	void setGlobalContextProperty (const QString& property, const QString& value) { global_context_properties.insert (property, value); };
 friend class RKWorkplace;
 /** type of this window */
 	int type;
@@ -131,6 +141,11 @@ friend class RKToolWindowBar;
 	RKToolWindowBar *tool_window_bar;
 	bool active;
 	RKMDIStandardActionClient *standard_client;
+/** @see globalContextProperty() */
+	QMap<QString, QString> global_context_properties;
+	QString generic_window_name;
+	QString help_url;
+	RKSettings::SettingsPage settings_page;
 };
 
 #endif
