@@ -2,7 +2,7 @@
                           rwindowcatcher.h  -  description
                              -------------------
     begin                : Wed May 4 2005
-    copyright            : (C) 2005, 2006, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2005, 2006, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -68,24 +68,36 @@ public:
 /** end looking out for new R X11 windows. If a new window was in fact created, this is captured by creating an RKCaughtX11Window
 @param new_cur_device the new active device number, i.e. the device number of the created window */
 	void stop (int new_cur_device);
+/** called from the R backend when the device history needs to be updated
+@param params the serialized parameters as supplied from R */
+	void updateHistory (QStringList params);
+/** Kill an R device
+@param device_number R device number of the device to kil */
+	void killDevice (int device_number);
 private:
 	int last_cur_device;
 };
 
 
 #include "rkmdiwindow.h"
+#include "../rbackend/rcommandreceiver.h"
+
+#include <QHash>
 
 class RKCaughtX11WindowPart;
 class KToggleAction;
+class KAction;
+class KSelectAction;
 class QXEmbedCopy;
 class QScrollArea;
 class KVBox;
 class RKProgressControl;
 class QX11EmbedContainer;
 class QWinHost;
+class KPassivePopup;
 
 /** An R X11 device window managed by rkward. */
-class RKCaughtX11Window : public RKMDIWindow {
+class RKCaughtX11Window : public RKMDIWindow, public RCommandReceiver {
 	Q_OBJECT
 public:
 /** ctor
@@ -103,6 +115,13 @@ public:
 	void prepareToBeAttached ();
 /** see prepareToBeAttached (). Reenable the dynamic_size_action */
 	void prepareToBeDetached ();
+/** returns the window corresponding the to given R device number (or 0 if no such window exists) */
+	static RKCaughtX11Window* getWindow (int device_number) { return device_windows.value (device_number); };
+	void updateHistoryActions (int history_length, int position, const QStringList &labels);
+/** Set a status message to be shown in a popup inside the window. The message persists until the given R command has finished, or until this function is called with an empty string.
+This should be used, when the plot is currently out-of-date (e.g. when loading a plot from history), _not_ when the window
+is simply busy (e.g. when saving the current plot to history). */
+	void setStatusMessage (const QString& message, RCommand* command=0);
 public slots:
 /** Fixed size action was (potentially) toggled. Update to the new state */
 	void fixedSizeToggled ();
@@ -121,24 +140,60 @@ public slots:
 	void copyDeviceToRObject ();
 	void duplicateDevice ();
 
+/** history navigation */
+	void firstPlot ();
+	void previousPlot ();
+	void nextPlot ();
+	void lastPlot ();
+	void gotoPlot (int index);
+	void forceAppendCurrentPlot ();
+	void removeCurrentPlot ();
+	void clearHistory ();
+	void showPlotInfo ();
+
+/** reimplemented to keep window alive while saving history */
+	bool close (bool also_delete);
+	void setKilledInR () { killed_in_r = true; };
 private slots:
 	void doEmbed ();
 private:
+	void rCommandDone (RCommand *command);
 	friend class RKCaughtX11WindowPart;	// needs access to the actions
 	int device_number;
+	bool killed_in_r;
 	WId embedded;
 	KVBox *xembed_container;
 	QScrollArea *scroll_widget;
 	KVBox *box_widget;
 	RKProgressControl *error_dialog;
+
+	static QHash<int, RKCaughtX11Window*> device_windows;
 #ifdef Q_WS_WIN
 	QWinHost *capture;
-#else
+#elif defined Q_WS_X11
 	QX11EmbedContainer *capture;
+#else
+	// a dummy to make things compile for now
+	QWidget *capture;
 #endif
 
 	bool dynamic_size;
 	KToggleAction *dynamic_size_action;
+	KAction *plot_prev_action;
+	KAction *plot_next_action;
+	KAction *plot_first_action;
+	KAction *plot_last_action;
+	KAction *plot_force_append_action;
+	KAction *plot_remove_action;
+	KAction *plot_clear_history_action;
+	KAction *plot_properties_action;
+	KSelectAction *plot_list_action;
+
+	KPassivePopup* status_popup;
+	RCommand* status_change_command;
+
+	int history_length;
+	int history_position;
 };
 
 /** Provides a KPart interface for RKCaughtX11Window. */
