@@ -15,10 +15,10 @@ if (!is.null (labels)) {
 	}
 }
 
-my.spss.data <<- data		# assign to globalenv()
+.GlobalEnv$my.spss.data <- data		# assign to globalenv()
 ## Print result
 rk.header("Import SPSS data", parameters=list("File", "../import_export_plugins_testfile.sav",
 	"Import as", "my.spss.data"))
 })
-.rk.rerun.plugin.link(plugin="rkward::import_spss", settings="convert_var_labels.state=1\ndata_frame.state=1\ndo_locale_conversion.state=0\ndoedit.state=0\nfile.selection=../import_export_plugins_testfile.sav\nlabels_limit.real=1.00\nsaveto.selection=my.spss.data\ntrim_labels.state=0\nuse_labels.state=1", label="Run again")
+.rk.rerun.plugin.link(plugin="rkward::import_spss", settings="convert_var_labels.state=1\ndata_frame.state=1\ndo_locale_conversion.state=0\ndoedit.state=0\nfile.selection=../import_export_plugins_testfile.sav\nlabels_limit.real=1.00\nsaveto.objectname=my.spss.data\nsaveto.parent=.GlobalEnv\ntrim_labels.state=0\nuse_labels.state=1", label="Run again")
 .rk.make.hr()
