@@ -15,10 +15,10 @@ if (!is.null (labels)) {
         }
 }
 
-my.stata.data <<- data		# assign to globalenv()
+.GlobalEnv$my.stata.data <- data		# assign to globalenv()
 ## Print result
 rk.header("Import Stata File", parameters=list("File", "../import_export_plugins_testfile.dta",
 	"Imported to", "my.stata.data"))
 })
-.rk.rerun.plugin.link(plugin="rkward::import_stata", settings="convert_dates.state=1\nconvert_factors.state=1\nconvert_underscore.state=0\ndoedit.state=0\nfile.selection=../import_export_plugins_testfile.dta\nmissing_type.state=0\nsaveto.selection=my.stata.data", label="Run again")
+.rk.rerun.plugin.link(plugin="rkward::import_stata", settings="convert_dates.state=1\nconvert_factors.state=1\nconvert_underscore.state=0\ndoedit.state=0\nfile.selection=../import_export_plugins_testfile.dta\nmissing_type.state=0\nsaveto.objectname=my.stata.data\nsaveto.parent=.GlobalEnv", label="Run again")
 .rk.make.hr()
