@@ -6,5 +6,5 @@ load (file="women.RData", envir=globalenv())
 rk.header("Load data", parameters=list("File", "women.RData",
 	"Import to environment", "globalenv()"))
 })
-.rk.rerun.plugin.link(plugin="rkward::load_r_object", settings="file.selection=women.RData\nother_env.state=0", label="Run again")
+.rk.rerun.plugin.link(plugin="rkward::load_r_object", settings="envir.active=0\nenvir.objectname=my.env\nenvir.parent=.GlobalEnv\nfile.selection=women.RData", label="Run again")
 .rk.make.hr()
